@@ -1,3 +1,5 @@
+import asyncio
+
 import janus
 import tarantool
 
@@ -28,9 +30,7 @@ class TarantoolTask(BaseTask):
         self.queue_name = tube.name
         self.connection = connection
         self._tube = tube
-        self._main_tnt = janus.Queue(loop=loop)
         super().__init__(loop, type(self).__name__, foo, args, bind, timeout, max_retries, retry_countdown, name)
-        self.loop.create_task(self._main_tnt_listener())
 
     def set_tube(self, task):
         """
@@ -44,14 +44,11 @@ class TarantoolTask(BaseTask):
     def reset(self):
         self._task, self.data = None, None
 
-    async def _main_tnt_listener(self):
-        while True:
-            func_name, args, timeout = await self._main_tnt.async_q.get()
-            await self.connection.call(func_name, args, timeout=timeout)
-            self._main_tnt.async_q.task_done()
+    async def _tnt_call(self, func_name, args, timeout):
+        return await self.connection.call(func_name, args, timeout=timeout)
 
     def __call__(self, func_name, args, timeout=-1):
-        """Async tarantool command execute. You may use self(<tarantool_command>) in task function.
+        """Tarantool command execute. You may use self(<tarantool_command>) in task function.
         Use this method if you want to redeclare ack method for example or bury, release task manually.
 
         :type func_name: str
@@ -59,20 +56,8 @@ class TarantoolTask(BaseTask):
         :type timeout: int
         :return:
         """
-        self._main_tnt.sync_q.put((func_name, args, timeout))
-
-    def tnt_sync_call(self, *args, **kwargs):
-        """Sync tarantool command execute. You may use self.tnt_sync_call(<tarantool_command>) in task function
-
-        :param args:
-        :param kwargs:
-        :return:
-        """
-        t = tarantool.connect(self.connection.host, self.connection.port, self.connection.username,
-                              self.connection.password, self.connection.encoding)
-        r = t.call(*args, **kwargs)
-        t.close()
-        return r
+        future = asyncio.run_coroutine_threadsafe(self._tnt_call(func_name, args, timeout=timeout), self.app.loop)
+        return future.result()
 
     @property
     def tube(self):
