@@ -5,7 +5,7 @@ LOGGING = {
     'disable_existing_loggers': True,
     'formatters': {
         'console': {
-            'format': '[%(asctime)s][%(levelname)s] %(name)s '
+            'format': '[%(asctime)s][%(levelname)s][thread-%(thread)d] %(name)s '
                       '%(filename)s:%(funcName)s:%(lineno)d | %(message)s',
             'datefmt': '%H:%M:%S',
         },
